pub struct NttMatrix<F: Field, K: ArraySize, L: ArraySize>(pub Array<NttVector<F, L>, K>);Expand description
A K x L matrix of NTT-domain polynomials.
Each vector represents a row of the matrix, so that multiplying on the right just requires iteration.
Multiplication on the right by vectors is the only defined operation, and is only defined when multiplication of NTT polynomials is defined.
Tuple Fields
0: Array<NttVector<F, L>, K>Implementations