Vector

Struct Vector 

pub struct Vector<F: Field, K: ArraySize>(pub Array<Polynomial<F>, K>);
A Vector is a vector of polynomials from R_q of length K.

Vectors can be added, subtracted, negated, and multiplied by field elements.

Tuple Fields

0: Array<Polynomial<F>, K>

Implementations

Source

impl<F: Field, K: ArraySize> Vector<F, K>

pub const fn new(x: Array<Polynomial<F>, K>) -> Self

Create a new vector.