pub struct Elem<F: Field>(pub F::Int);Expand description
An Elem is a member of the specified prime-order field.
Elements can be added, subtracted, multiplied, and negated, and the overloaded operators will ensure both that the integer values remain in the field, and that the reductions are done efficiently.
For addition and subtraction, a simple conditional subtraction is used; for multiplication, Barrett reduction.
Tuple Fields
0: F::IntImplementations