pub struct Polynomial<F: Field>(pub Array<Elem<F>, U256>);Expand description
A Polynomial is a member of the ring R_q = Z_q[X] / (X^256) of degree-256 polynomials
over the finite field with prime order q.
Polynomials can be added, subtracted, negated, and multiplied by field elements.
Tuple Fields
0: Array<Elem<F>, U256>Implementations