pub struct Vector<F: Field, K: ArraySize>(pub Array<Polynomial<F>, K>);Expand description
A Vector is a vector of polynomials from R_q of length K.
Vectors can be added, subtracted, negated, and multiplied by field elements.
Tuple Fields
0: Array<Polynomial<F>, K>Implementations